===============
oslo.middleware
===============

.. image:: https://img.shields.io/pypi/v/oslo.middleware.svg
    :target: https://pypi.org/project/oslo.middleware/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/oslo.middleware.svg
    :target: https://pypi.org/project/oslo.middleware/
    :alt: Downloads

Oslo middleware library includes components that can be injected into
wsgi pipelines to intercept request/response flows. The base class can be
enhanced with functionality like add/delete/modification of http headers
and support for limiting size/connection etc.

* Free software: Apache license
* Documentation: https://docs.openstack.org/oslo.middleware/latest/
* Source: https://opendev.org/openstack/oslo.middleware
* Bugs: https://bugs.launchpad.net/oslo.middleware
* Release notes: https://docs.openstack.org/releasenotes/oslo.middleware/
